@@ -11,8 +11,10 @@ from ctypes import ArgumentError
 
 from shapely.coords import required
 from shapely.geos import lgeos
-from shapely.geometry.base import BaseMultipartGeometry, exceptNull
-from shapely.geometry.point import Point, geos_point_from_py
+from shapely.geometry.base import (
+    BaseMultipartGeometry, exceptNull, geos_geom_from_py
+)
+from shapely.geometry import point
 from shapely.geometry.proxy import CachingGeometryProxy
 
 __all__ = ['MultiPoint', 'asMultiPoint']
@@ -51,14 +53,14 @@ class MultiPoint(BaseMultipartGeometry):
         """
         super(MultiPoint, self).__init__()
 
-        if points is None:
+        if points is None or len(points) == 0:
             # allow creation of empty multipoints, to support unpickling
             pass
         else:
             self._geom, self._ndim = geos_multipoint_from_py(points)
 
     def shape_factory(self, *args):
-        return Point(*args)
+        return point.Point(*args)
 
     @property
     def __geo_interface__(self):
@@ -67,6 +69,25 @@ class MultiPoint(BaseMultipartGeometry):
             'coordinates': tuple([g.coords[0] for g in self.geoms])
             }
 
+    def svg(self, scale_factor=1., fill_color=None):
+        """Returns a group of SVG circle elements for the MultiPoint geometry.
+
+        Parameters
+        ==========
+        scale_factor : float
+            Multiplication factor for the SVG circle diameters.  Default is 1.
+        fill_color : str, optional
+            Hex string for fill color. Default is to use "#66cc99" if
+            geometry is valid, and "#ff3333" if invalid.
+        """
+        if self.is_empty:
+            return '<g />'
+        if fill_color is None:
+            fill_color = "#66cc99" if self.is_valid else "#ff3333"
+        return '<g>' + \
+            ''.join(p.svg(scale_factor, fill_color) for p in self) + \
+            '</g>'
+
     @property
     @exceptNull
     def ctypes(self):
@@ -101,7 +122,7 @@ class MultiPoint(BaseMultipartGeometry):
 class MultiPointAdapter(CachingGeometryProxy, MultiPoint):
 
     context = None
-    _owned = False
+    _other_owned = False
 
     def __init__(self, context):
         self.context = context
@@ -134,6 +155,9 @@ def asMultiPoint(context):
 
 
 def geos_multipoint_from_py(ob):
+    if isinstance(ob, MultiPoint):
+        return geos_geom_from_py(ob)
+
     # If numpy is present, we use numpy.require to ensure that we have a
     # C-continguous array that owns its data. View data will be copied.
     ob = required(ob)
@@ -157,7 +181,7 @@ def geos_multipoint_from_py(ob):
         subs = (c_void_p * m)()
 
         for i in range(m):
-            geom, ndims = geos_point_from_py(cp[n*i:n*i+2])
+            geom, ndims = point.geos_point_from_py(cp[n*i:n*i+2])
             subs[i] = cast(geom, c_void_p)
 
     except AttributeError:
@@ -175,7 +199,7 @@ def geos_multipoint_from_py(ob):
         # add to coordinate sequence
         for i in range(m):
             coords = ob[i]
-            geom, ndims = geos_point_from_py(coords)
+            geom, ndims = point.geos_point_from_py(coords)
             subs[i] = cast(geom, c_void_p)
             
     return lgeos.GEOSGeom_createCollection(4, subs, m), n
